@@ -104,13 +104,14 @@ class Component:
 
     def download(self, branch=''):
         if True:
-            if self.version:
-                branch = self.version
-                v = branch.split('?')
-                if len(v) > 1:
-                    branch = v[0].strip()
-            elif not branch:
-                branch = 'master'
+            if not branch:
+                if self.version:
+                    branch = self.version
+                    v = branch.split('?')
+                    if len(v) > 1:
+                        branch = v[0].strip()
+                else:
+                    branch = 'master'
             # if not self.conf.repo.endswith('.git'):
             #     repo_url = os.path.join(self.conf.repo, '%s.git' % self.name)
             if not self.repo_url:
@@ -164,7 +165,7 @@ class Component:
             else:
                 zipf.extractall('.')
 
-    def upload(self, repo_base_url=''):
+    def upload(self, message, repo_base_url=''):
         if not self.check_file_integrity():
             put_string("There is no `README.md` or `package.yaml` file found in %s component,please add it first." % self.name)
             exit(-1)
@@ -181,7 +182,7 @@ class Component:
             git.set_remote(repo_url)
             branch = self.version
             git.pull(branch)
-            git.import_path(self.path, branch)
+            git.import_path(self.path, branch, message)
         except:
             put_string("Component `%s` upload fail." % self.name)
 
@@ -262,6 +263,8 @@ class Component:
         for d in pack.depends:
             if type(d) == dict:
                 self.depends.append(d)
+            elif type(d) == str:
+                self.depends.append({d: ""})
 
         # add component version in defconfig
         ver_key = "%s_SW_VERSION" % self.name.upper()
@@ -272,6 +275,32 @@ class Component:
         return True
 
     def variable_convert(self, varList):
+        # script
+        def script_filename_convert(root_path, script_file):
+            script_filename = varList.convert(script_file)
+            if script_filename != None:
+                script_file = os.path.join(root_path, script_filename)
+            return script_file
+
+        self.build_config.submodule_script = script_filename_convert(self.path, self.build_config.submodule_script)
+        self.build_config.prebuild_script = script_filename_convert(self.path, self.build_config.prebuild_script)
+        self.build_config.postbuild_script = script_filename_convert(self.path, self.build_config.postbuild_script)
+        self.build_config.postimage_script = script_filename_convert(self.path, self.build_config.postimage_script)
+        if self.build_config.submodule_script:
+            cmd = ""
+            # script_file might have args
+            real_file = self.build_config.submodule_script
+            real_args = ""
+            idx = self.build_config.submodule_script.find(" --")
+            if idx > 0:
+                real_file = self.build_config.submodule_script[:idx]
+                real_args = self.build_config.submodule_script[idx:]
+            if real_file.endswith(".py"):
+                cmd = "python "
+            cmd += "\"%s\" %s" % (real_file, real_args)
+            put_string("Run submodule script '%s'..." % cmd)
+            os.system(cmd)
+
         # include
         incs = []
         for inc in self.build_config.include:
@@ -345,17 +374,6 @@ class Component:
                 sources.append(fn)
         self.source_files_updated = sources
 
-        # script
-        def script_filename_convert(root_path, script_file):
-            script_filename = varList.convert(script_file)
-            if script_filename != None:
-                script_file = os.path.join(root_path, script_filename)
-            return script_file
-        
-        self.build_config.prebuild_script = script_filename_convert(self.path, self.build_config.prebuild_script)
-        self.build_config.postbuild_script = script_filename_convert(self.path, self.build_config.postbuild_script)
-        self.build_config.postimage_script = script_filename_convert(self.path, self.build_config.postimage_script)
-
         def export_convert(convert):
             exports = []
             for ins in convert:
