@@ -495,7 +495,7 @@ def riscv_cpu_id(cpu):
         return 'rv32fd_32gpr'
     elif a == 'c906':
         return 'rv64_32gpr'
-    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v':
+    elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v' or a == 'c906d':
         return 'rv64fd_32gpr'
     else:
         put_string("%s not support yet." % a)
