@@ -80,7 +80,7 @@ Create project from templet
             opt.destdir = conf.yoc_path
             os.chdir(opt.destdir)
             if created_newdir:
-                shutil.rmtree(created_newdir)
+                rmtree_enhanced(created_newdir)
                 created_newdir = ""
             put_string("Workspace is already existed at %s." % opt.destdir)
         cur_dir = os.getcwd()
@@ -92,7 +92,7 @@ Create project from templet
             if created_newdir:
                 # if cur_dir == created_newdir:
                 os.chdir(os.path.dirname(cur_dir))
-                shutil.rmtree(created_newdir)
+                rmtree_enhanced(created_newdir)
             exit(-1)
 
         # aos init
@@ -114,21 +114,33 @@ Create project from templet
                 if created_newdir:
                     # if cur_dir == created_newdir:
                     os.chdir(os.path.dirname(cur_dir))
-                    shutil.rmtree(created_newdir)
+                    rmtree_enhanced(created_newdir)
                 exit(-1)
+        elif conf.init:
+            if opt.repo or opt.branch:
+                # default url is conf.repo, and default branch is master
+                opt.repo = conf.repo if not opt.repo else opt.repo
+                opt.branch = "master" if not opt.branch else opt.branch
+                if opt.repo != conf.repo or opt.branch != conf.branch:
+                    put_string("\nThe workspace is already initialized as %s(%s)." % (conf.repo, conf.branch))
+                    put_string("It can not be reinitialzed to %s(%s)" % (opt.repo, opt.branch))
+                    if created_newdir:
+                        os.chdir(os.path.dirname(cur_dir))
+                        rmtree_enhanced(created_newdir)
+                    exit(-1)
 
         def remove_project_files(cur_dir, created_newdir, inited_workspace):
             if created_newdir:
                 # if cur_dir == created_newdir:
                 os.chdir(os.path.dirname(cur_dir))
-                shutil.rmtree(created_newdir)
+                rmtree_enhanced(created_newdir)
             elif inited_workspace:
                 os.remove(".aos")
-                shutil.rmtree("components")
-                shutil.rmtree("kernel")
-                shutil.rmtree("hardware")
-                shutil.rmtree("solutions")
-                shutil.rmtree("documentation")
+                rmtree_enhanced("components")
+                rmtree_enhanced("kernel")
+                rmtree_enhanced("hardware")
+                rmtree_enhanced("solutions")
+                rmtree_enhanced("documentation")
 
         # aos install [templet] and [board]
         try:
@@ -161,15 +173,9 @@ Create project from templet
                 put_string("AosCommand error:", e)
                 remove_project_files(cur_dir, created_newdir, inited_workspace)
                 exit(-1)
-            try:
-                templet_path = os.path.join(cur_dir, "solutions", opt.templet)
-                shutil.rmtree(templet_path)
-            except:
-                delete_ret = 1
-                if get_host_os() == 'Win32':
-                    delete_ret = os.system("cmd /c rmdir /s /q %s" % templet_path) >> 8
-                if delete_ret != 0:
-                    put_string("Delete %s failed. Please delete it manually." % templet_path)
+
+            templet_path = os.path.join(cur_dir, "solutions", opt.templet)
+            rmtree_enhanced(templet_path)
 
         # update package.yaml of solution: set the specified board as default one
         filename = os.path.join(cur_dir, "solutions", solution_name, 'package.yaml')
@@ -189,4 +195,5 @@ Create project from templet
 
         # success
         put_string("Create solution \"%s\" successfully." % solution_name)
+        check_remote_version()
         return 0
\ No newline at end of file
