@@ -20,7 +20,7 @@ all_toolchain_url = {
     'Win32':{
     'csky-abiv2-elf': '',
     'riscv64-unknown-elf': '',
-    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git'
+    'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git -b aos'
     }, 
     'Linux32':{
     'csky-abiv2-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz',
@@ -53,15 +53,15 @@ class ToolchainYoC:
             return
 
         if os.path.exists(toolchain_path):
-            shutil.rmtree(toolchain_path)
-            put_string("remove corrupt directory %s." % toolchain_path)
+            put_string("removing corrupt directory %s." % toolchain_path)
+            rmtree_enhanced(toolchain_path)
         
         toolchain_url = all_toolchain_url[host_os][arch]
         if not toolchain_url:
             put_string("Url is empty!")
             return
         put_string("Start to download toolchain: %s. \nPlease be patient for a few minutes..." % arch)
-        pattern = re.compile("(.*)\s+\-b\s+(.*)")
+        pattern = re.compile(r'(.*)\s+\-b\s+(.*)')
         branch = "master"
         match = pattern.match(toolchain_url)
         if match:
@@ -130,7 +130,9 @@ class ToolchainYoC:
                 path = os.path.join(self.basepath, arch, "main", "bin", arch + '-gcc')
                 path = which(path)
             if path:
-                shutil.rmtree(os.path.join(self.basepath, arch))
+                toolchain_path = os.path.join(self.basepath, arch)
+                if rmtree_enhanced(toolchain_path) != 0:
+                    exit(-1)
                 put_string("The toolchain \"%s\" is uninstalled." % path)
             else:
                 put_string("The toolchain \"%s\" is not existed." % arch)
