@@ -15,6 +15,8 @@ import re
 import platform
 import subprocess
 import chardet
+import glob
+import shutil
 
 try:
     from urlparse import urlparse
@@ -479,6 +481,16 @@ def get_host_os():
         host_os = None
     return host_os
 
+def find_latest_file(src):
+    latest_modified_time = 0.0
+    latest_file = ""
+    for s in glob.iglob(src):
+        modified_time = os.stat(s).st_mtime
+        if modified_time > latest_modified_time:
+            latest_modified_time = modified_time
+            latest_file = s
+    return latest_file
+
 def get_elf_bin_file(filename):
     elf_file = ''
     bin_file = ''
@@ -497,7 +509,13 @@ def get_elf_bin_file(filename):
                     match = bin_pattern.search(line)
                     if match:
                         bin_file = match.group(1)
-                    return elf_file, bin_file
+                    break
+            # if not specified, search in out directory
+            if not elf_file:
+                elf_file = find_latest_file(os.path.join("out", "*@*.elf"))
+            if not bin_file:
+                bin_file = find_latest_file(os.path.join("out", "*@*.bin"))
+            return elf_file, bin_file
     except Exception as e:
         put_string("(%s) in file:%s" % (str(e), filename))
         exit(-1)
@@ -603,15 +621,38 @@ def change_dir_to_solution(yoc_path):
                 put_string("change dir to %s." % new_dir)
     return cur_dir
 
+def check_version_text(lines):
+    text = ""
+    pattern = re.compile(r'aos-tools\s+([0-9\.]*)\s+([0-9\.]*)')
+    for line in lines:
+        try:
+            if type(line) != str:
+                encode = chardet.detect(line)
+                line = line.decode(encode["encoding"]).strip()
+        except UnicodeDecodeError:
+            line = " "
+            pass
+        if line.find("aos-tools") >= 0:
+            match = pattern.search(line)
+            if match:
+                text = line
+                put_string("\n\n[NOTICE]The lastest version aos-tools is %s. You can upgrade it as below:" % match.group(2))
+                put_string("python -m pip install -U aos-tools")
+                break
+    return text
+
 def check_remote_version():
     need_check = False
-    new_version = False
     ver_file = home_path('.aliot/version')
     if os.path.isfile(ver_file):
         modified_time = os.stat(ver_file).st_mtime
         now = time.time()
         if modified_time > now or (now - modified_time) > 4 * 3600:
             need_check = True
+        else:
+            with open(ver_file, 'r') as f:
+                lines = f.readlines()
+                check_version_text(lines)
     else:
         need_check = True
         aliot_dir = home_path('.aliot')
@@ -621,25 +662,23 @@ def check_remote_version():
         put_string("\n\nChecking latest version of aos-tools from pip server...")
         script_process = subprocess.Popen("python -m pip list --outdated", shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
         lines = script_process.stdout.readlines()
-        pattern = re.compile("aos-tools\s+([0-9\.]*)\s+([0-9\.]*)")
-        for text in lines:
-            try:
-                encode = chardet.detect(text)
-                text = text.decode(encode["encoding"]).strip()
-            except UnicodeDecodeError:
-                text = " "
-                pass
-            if text.find("aos-tools") >= 0:
-                match = pattern.search(text)
-                if match:
-                    with open(ver_file, 'w') as f:
-                        f.write(text)
-                    put_string("The lastest version aos-tools is %s. You can upgrade it as below:" % match.group(2))
-                    put_string("python -m pip install -U aos-tools")
-                    new_version = True
-        if not new_version:
+        line = check_version_text(lines)
+        if line:
+            with open(ver_file, 'w') as f:
+                f.write(line)
+        else:
             with open(ver_file, 'w') as f:
                 f.write("latest")
             put_string("It is already latest version.")
 
-
+def rmtree_enhanced(rm_path):
+    try:
+        delete_ret = 0
+        shutil.rmtree(rm_path)
+    except:
+        delete_ret = 1
+        if get_host_os() == 'Win32':
+            delete_ret = os.system("cmd /c rmdir /s /q \"%s\"" % rm_path) >> 8
+        if delete_ret != 0:
+            put_string("Delete %s failed. Please delete it manually." % rm_path)
+    return delete_ret
