@@ -567,6 +567,7 @@ class YoC:
                 cmp = Component(self.conf)
                 cmp.name = p.name
                 cmp.type = p.type
+                cmp.version = p.latest_version
                 cmp.description = p.desc
                 cmp.repo_url = get_repo_url(self.default_mani.remotes, p)
                 cmp.path = get_cmpt_path(cmp.name, cmp.type)
@@ -580,10 +581,17 @@ class YoC:
         for component in self.occ_components:
             for d in depends:
                 if type(d) == dict:
+                    # comp: "", or comp: version, or comp: "? <cond>", or comp: version ? <cond>
                     name = list(d.keys())[0]
+                    version = list(d.values())[0]
+                    v = version.split('?')
+                    if len(v) > 1:
+                        version = v[0].strip()
+                    # if specify version, update it; otherwise, use its latest_version from default.yaml
                     if component.name == name:
-                        component.version = list(d.values())[0]
-                        # print("update %s version:%s" % (component.name, component.version))
+                        if version:
+                            component.version = version
+                            # print("update %s version:%s" % (component.name, component.version))
                         break
             
     def gitee_update(self):
